from django.contrib import admin

from trainvel.core.models import Station


class StationInline(admin.TabularInline):
    model = Station
    extra = 0
    autocomplete_fields = ('parent_station', 'same_as',)
    show_change_link = True
    ordering = ('name',)
    readonly_fields = ('id',)
    fk_name = 'parent_station'


@admin.register(Station)
class StationAdmin(admin.ModelAdmin):
    list_display = ('name', 'country', 'uic', 'latitude', 'longitude',)
    list_filter = ('country', 'is_city', 'is_main_station', 'is_airport', 'is_suggestable',
                   'country_hint', 'main_station_hint',)
    search_fields = ('name', 'slug',)
    autocomplete_fields = ('parent_station', 'same_as',)
    inlines = [StationInline]
