import csv

import requests
from django.core.management import BaseCommand
from tqdm import tqdm

from trainvel.core.models import Station


class Command(BaseCommand):
    def handle(self, *args, **options):
        def convert_value(value: str) -> str:
            return True if value == 't' else False if value == 'f' else (value or None)

        stations, stations_without_fk = [], []

        STATIONS_URL = "https://raw.githubusercontent.com/trainline-eu/stations/master/stations.csv"
        with requests.get(STATIONS_URL, stream=True) as resp:
            for row in csv.DictReader(tqdm(resp.iter_lines(decode_unicode=True)), delimiter=';'):
                row: dict
                values = {k.replace(':', '_').replace('normalised_code', 'normalized_code_trainline')
                          .replace('same_as', 'same_as_id'): convert_value(v)
                          for k, v in row.items()}
                values_without_fk = values.copy()
                del values_without_fk['same_as_id']
                del values_without_fk['parent_station_id']
                stations.append(Station(**values))
                stations_without_fk.append(Station(**values_without_fk))

        Station.objects.bulk_create(stations_without_fk, update_conflicts=True, unique_fields=['id'],
                                    update_fields=[k for k in values_without_fk.keys() if k != 'id'])
        Station.objects.bulk_create(stations, update_conflicts=True, unique_fields=['id'],
                                    update_fields=['same_as_id', 'parent_station_id'])
